// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'

export const defaultStyles = {
  image: 'is-64x64 pa2',
  title: 'f5',
}

const Horizontal = ({
  item: { image, title, description, actions = [] },
  reverse,
  className,
  theme,
  Link,
}: {
  item: Item,
  reverse?: boolean,
  className?: string,
  theme: { [key: string]: string },
  Link: any,
}) => (
  <div className={cn('flex flex-wrap items-center', theme.root, className, { 'flex-row-reverse': reverse })}>
    <div className={theme.imageWrapper}>
      <img className={cn('flex-none-ns', theme.image)} src={image} alt={title} />
    </div>
    <div className={theme.body}>
      <div className={theme.title}>{title}</div>
      <div className={theme.description}>{description}</div>
      <div className={theme.footer}>
        {actions.length > 0 && actions.map(action => (
          <div className="h3 tc mt2 mt3-ns">
            <Link
              className={cn('button', theme.action, { 'is-outlined': action.secondary })}
              to={action.href}
            >
              {action.label}
            </Link>
          </div>
        ))}
      </div>
    </div>
  </div>
)

Horizontal.defaultProps = {
  className: null,
  reverse: false,
}

export default themr('Horizontal', {}, { composeTheme: 'softly' })(Horizontal)
